@@ -73,8 +73,7 @@
 #include "net-locale.h"
 
 #if HAVE_AFINET6
-#include <netinet6/in6.h>
-#include <netinet6/ipv6.h>
+#include <netinet/ip6.h>
 #endif
 
 /* prototypes for statistics.c */
